.. _api-index:

####################
  The Matplotlib API
####################

.. htmlonly::

   :Release: |version|
   :Date: |today|

.. toctree::
   :maxdepth: 1

   api_changes.rst
   matplotlib_configuration_api.rst
   afm_api.rst
   animation_api.rst
   artist_api.rst
   axes_api.rst
   axis_api.rst
   index_backend_api.rst
   cbook_api.rst
   cm_api.rst
   collections_api.rst
   colorbar_api.rst
   colors_api.rst
   dates_api.rst
   figure_api.rst
   font_manager_api.rst
   gridspec_api.rst
   legend_api.rst
   mathtext_api.rst
   mlab_api.rst
   nxutils_api.rst
   path_api.rst
   pyplot_api.rst
   spines_api.rst
   ticker_api.rst
   tight_layout_api.rst
   units_api.rst
   widgets_api.rst
